@@ -483,13 +483,13 @@ def g_counter(data, arities, cols, weights=None):
     return G, dof
 
 
-# statistical fisher's z test
-def z_test(data, varnames, cols):
-    data = pandas.DataFrame(data, columns=varnames)
+# Pearson's correlation test
+def cor_test(data, cols):
+    data = pandas.DataFrame(data)
     if len(cols) == 2:
-        return pg.partial_corr(data, varnames[cols[0]], varnames[cols[1]])['p-val'][0]
+        return pg.partial_corr(data, cols[0], cols[1])['p-val'][0]
     elif len(cols) > 2:
-        return pg.partial_corr(data, varnames[cols[0]], varnames[cols[1]], [varnames[i] for i in cols[2:]])['p-val'][0]
+        return pg.partial_corr(data, cols[0], cols[1], cols[2:])['p-val'][0]
     else:
         raise Exception('Length of input cols is less than 2')
 
