@@ -166,9 +166,8 @@ def bic_g(data, cols, weights=None):
     if len(y) <= X.shape[1]:
         bic = np.nan
     else:
-        W = np.diag(weights)
-        b = np.linalg.inv(X.T @ W @ X) @ X.T @ W @ y
-        ssr = np.sum((y - X @ b) ** 2 * weights)
+        b = np.linalg.inv(X.T @ X) @ X.T @ y
+        ssr = np.sum((y - X @ b) ** 2)
         df = X.shape[0] - X.shape[1]
         bic = - X.shape[0] / 2 * np.log(2 * np.pi * ssr / df) - df / 2 - np.log(X.shape[0]) / 2 * (1 + X.shape[1])
     return bic
