@@ -6,7 +6,7 @@ import numpy as np
 import pandas
 
 pandas.options.mode.chained_assignment = None
-from .accessory import g_test, z_test, find_causes, pairwise, dag2cpdag, independence_test, orient_v_structure, \
+from .accessory import g_test, cor_test, find_causes, pairwise, dag2cpdag, independence_test, orient_v_structure, \
     orient_propagation, to_bnlearn
 from .score import local_score
 
@@ -599,7 +599,7 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
             for i in range(len(varnames) - 1):
                 for j in range(i + 1, len(varnames)):
                     cols = [i, j]
-                    p = g_test(data, cols) if datatype == 'category' else z_test(data, varnames, cols)
+                    p = g_test(data, cols) if datatype == 'category' else cor_test(data, cols)
                     if p > thres:
                         candidate[varnames[i]].remove(varnames[j])
                         candidate[varnames[j]].remove(varnames[i])
@@ -727,8 +727,8 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
                                                             cache_data, cache_weights, method)
                     if len(cache_data[W]) != 0:
                         cols = [i, j]
-                        p = g_test(cache_data[W], cols, cache_weights[W]) if datatype == 'category' else z_test(
-                            cache_data[W], varnames, cols)
+                        p = g_test(cache_data[W], cols, cache_weights[W]) if datatype == 'category' else cor_test(
+                            cache_data[W], cols)
                         if p > thres:
                             candidate[varnames[i]].remove(varnames[j])
                             candidate[varnames[j]].remove(varnames[i])
